pub enum AccessType {
Ram = 0,
Mmap = 1,
}Expand description
Defines where the index resides during search:
- Ram (the complete index is preloaded to Ram when opening the index)
- Mmap (the index is accessed via memory-mapped files). See architecture.md for details.
- At commit the data is serialized to disk for persistence both in Ram and Mmap mode.
- The serialization format is identical for Ram and Mmap mode, allowing to change it retrospectively.
Variants
Ram = 0
Ram (the complete index is preloaded to Ram when opening the index).
- Index size is limited by available RAM size.
- Slightly fastesr search speed.
- Higher index loading time.
- Higher RAM usage.
Mmap = 1
Mmap (the index is accessed via memory-mapped files). See architecture.md for details.
- Enables index size scaling beyond RAM size.
- Slightly slower search speed compared to Ram.
- Faster index loading time compared to Ram.
- Lower RAM usage.