DeleteDocumentsByQuery

Trait DeleteDocumentsByQuery 

pub trait DeleteDocumentsByQuery {
    // Required method
    async fn delete_documents_by_query(
        &self,
        query_string: String,
        query_type_default: QueryType,
        offset: usize,
        length: usize,
        include_uncommitted: bool,
        field_filter: Vec<String>,
        facet_filter: Vec<FacetFilter>,
        result_sort: Vec<ResultSort>,
    );
}
Delete documents from index by query Delete and search have identical parameters. It is recommended to test with search prior to delete to verify that only those documents are returned that you really want to delete.

Required Methods

async fn delete_documents_by_query( &self, query_string: String, query_type_default: QueryType, offset: usize, length: usize, include_uncommitted: bool, field_filter: Vec<String>, facet_filter: Vec<FacetFilter>, result_sort: Vec<ResultSort>, )

Delete documents from index by query Delete and search have identical parameters. It is recommended to test with search prior to delete to verify that only those documents are returned that you really want to delete.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl DeleteDocumentsByQuery for IndexArc

Delete documents from index by query Delete and search have identical parameters. It is recommended to test with search prior to delete to verify that only those documents are returned that you really want to delete.