pub enum RangeType {
CountWithinRange,
CountAboveRange,
CountBelowRange,
}Expand description
Create query_list and non_unique_query_list blockwise intersection : if the corresponding blocks with a 65k docid range for each term have at least a single docid, then the intersect_docid within a single block is executed (=segments?) specifies how to count the frequency of numerical facet field values
Variants
CountWithinRange
within the specified range
CountAboveRange
within the range and all ranges above
CountBelowRange
within the range and all ranges below